@@ -9,8 +9,12 @@ use std::path::PathBuf;
 pub trait Properties {
     /// This function returns a new instance of `PCIDevice` struct using the given `path`.
     ///
-    /// ## Examples:
+    /// ## Examples
+    ///
     /// ```
+    /// use aparato::PCIDevice;
+    /// use aparato::traits::*;
+    ///
     /// // PCIDevice::new() can autocomplete the path to the PCIDevice
     /// // if it isn't provided.
     ///
@@ -37,49 +41,50 @@ pub trait Properties {
     // Getters...
 
     /// This function returns the `PCIDevice` path.
-    #[doc(hidden)]
     fn path(&self) -> PathBuf;
 
     /// This function returns the `PCIDevice` address.
-    #[doc(hidden)]
     fn address(&self) -> String;
 
     /// This function returns the `PCIDevice` class ID.
-    #[doc(hidden)]
     fn class_id(&self) -> String;
 
     /// This function returns the `PCIDevice` vendor ID.
-    #[doc(hidden)]
     fn vendor_id(&self) -> String;
 
     /// This function returns the `PCIDevice` device ID.
-    #[doc(hidden)]
     fn device_id(&self) -> String;
 
     /// This function returns the `PCIDevice` NUMA node.
-    #[doc(hidden)]
     fn numa_node(&self) -> isize;
 
     /// This function returns the `PCIDevice` class name.
-    #[doc(hidden)]
     fn class_name(&self) -> String;
 
     /// This function returns the `PCIDevice` vendor name.
-    #[doc(hidden)]
     fn vendor_name(&self) -> String;
 
     /// This function returns the `PCIDevice` device name.
-    #[doc(hidden)]
     fn device_name(&self) -> String;
 
     /// This function returns whether the `PCIDevice` is enabled.
-    #[doc(hidden)]
     fn enabled(&self) -> bool;
 
     /// This function returns whether the `PCIDevice` is enabled.
-    #[doc(hidden)]
+    fn d3cold_allowed(&self) -> bool;
+
+    /// This function returns whether the `PCIDevice` is enabled.
     fn revision(&self) -> String;
 
+    /// This function returns the `PCIDevice` subsystem vendor.
+    fn subsystem_name(&self) -> String;
+
+    /// This function returns the `PCIDevice` subsystem vendor.
+    fn subsystem_vendor_id(&self) -> String;
+
+    /// This function returns the `PCIDevice` subsystem vendor.
+    fn subsystem_device_id(&self) -> String;
+
     // Setters...
 
     /// Set the `path` field of the `PCIDevice`.
@@ -118,6 +123,10 @@ pub trait Properties {
     #[doc(hidden)]
     fn set_enabled(&mut self);
 
+    /// This function sets the `d3cold_allowed` field of the `PCIDevice`.
+    #[doc(hidden)]
+    fn set_d3cold_allowed(&mut self);
+
     /// This function sets the `vendor_name` field of the `PCIDevice`.
     #[doc(hidden)]
     fn set_vendor_name(&mut self, name: String);
@@ -125,6 +134,18 @@ pub trait Properties {
     /// This function sets the `device_name` field of the `PCIDevice`.
     #[doc(hidden)]
     fn set_device_name(&mut self, name: String);
+
+    /// This function sets the `subsystem_vendor_id` field of the `PCIDevice`.
+    #[doc(hidden)]
+    fn set_subsystem_device_id(&mut self);
+
+    /// This function sets the `subsystem_device_id` field of the `PCIDevice`.
+    #[doc(hidden)]
+    fn set_subsystem_vendor_id(&mut self);
+
+    /// This function sets the `subsystem_name` field of the `PCIDevice`.
+    #[doc(hidden)]
+    fn set_subsystem_name(&mut self, name: String);
 }
 
 pub trait Fetch {
